# WARNING: This package is synced with Fedora

%define major	2
%define libname	%mklibname %{name} %{major}

%bcond_with bootstrap

%global use_alternatives 1
%global lspp 0

# {_exec_prefix}/lib/cups is correct, even on x86_64.
# It is not used for shared objects but for executables.
# It's more of a libexec-style ({_libexecdir}) usage,
# but we use lib for compatibility with 3rd party drivers (at upstream request).
%global cups_serverbin %{_exec_prefix}/lib/cups

Summary:	CUPS printing system - Server package
Name:		cups
Version:	2.2.13
%define 	subrel 5
Release:	%mkrel 1
License:	GPLv2+ and LGPLv2+ with exceptions and AML
Group:		System/Printing
Url:		http://www.cups.org

Source0: https://github.com/apple/cups/releases/download/v%{version}/cups-%{version}-source.tar.gz

# Logrotate configuration
Source6: cups.logrotate
# Backend for NCP protocol
Source7: ncp.backend
Source8: macros.cups
# Backend filter for nprint (Novell client) from Mark Horn
# (mark@hornclan.com)
Source11: http://www.hornclan.com/~mark/cups/nprint.2002011801
Source14: http://www.linuxprinting.org/download/printing/photo_print
# Perl script for automatic configuration of CUPS, especially access
# restrictions and broadcasting
Source15: correctcupsconfig
Source16: cjktexttops
# Nice level for now. bug #16387
Source18: cups.sysconfig

### FEDORA PATCHES ###

# some man pages are shipped gzipped, don't do it 
Patch1: cups-no-gzip-man.patch
# PAM enablement, very old patch, not even git can track when or why
# the patch was added.
Patch2: cups-system-auth.patch
# cups-config from devel package conflicted on multilib arches,
# fixed hack with pkg-config calling for gnutls' libdir variable
Patch3: cups-multilib.patch
# if someone makes a change to banner files, then there will <banner>.rpmnew
# with next update of cups-filters - this patch makes sure the banner file 
# changed by user is used and .rpmnew or .rpmsave is ignored
# Note: This could be rewrite with use a kind of #define and send to upstream
Patch5: cups-banners.patch
# don't export ssl libs to cups-config - can't find the reason.
Patch7: cups-no-export-ssllibs.patch
# enables old uri usb:/dev/usb/lp0 - leave it here for users of old printers
Patch8: cups-direct-usb.patch
# fix for redhat dbus spooler - adding new dbus functions to backend/ipp.c
# -> initialize dbus connection and sending dbus broadcast about job queued
# on remote queue with QueueChanged type for PRINTER_CHANGED, JOB_STATE_CHANGED
# and PRINTER_STATE_CHANGED events 
Patch12: cups-eggcups.patch
# when system workload is high, timeout for cups-driverd can be reached -
# increase the timeout
Patch13: cups-driverd-timeout.patch
# cupsd implement its own logrotate, but when MaxLogSize 0 is used, logrotated
# takes care of it
Patch15: cups-logrotate.patch
# usb backend didn't get any notification about out-of-paper because of kernel 
Patch16: cups-usb-paperout.patch
# uri compatibility with old Fedoras
Patch19: cups-uri-compat.patch
# fixing snmp oid for hp printer - upstream doesn't want to support too much
# snmp backend, because it's deprecated
Patch22: cups-hp-deviceid-oid.patch
# same as HP OID
Patch24: cups-ricoh-deviceid-oid.patch
# change to notify type, because when it fails to start, it gives a error
# message + renaming org.cups.cupsd names, because we have cups units in
# in older Fedoras
Patch25: cups-systemd-socket.patch
# use IP_FREEBIND, because cupsd cannot bind to not yet existing IP address
# by default
Patch30: cups-freebind.patch
# add support of multifile
Patch35: cups-ipp-multifile.patch
# prolongs web ui timeout
Patch36: cups-web-devices-timeout.patch
# needs to be set to Yes to avoid race conditions
Patch37: cups-synconclose.patch
# ypbind must be started before cups if NIS configured
Patch38: cups-ypbind.patch
# failover backend for implementing failover functionality
# TODO: move it to the cups-filters upstream
Patch39: cups-failover-backend.patch

# selinux and audit enablement for CUPS - needs work and CUPS upstream wants
# to have these features implemented their way in the future
Patch100: cups-lspp.patch

# reported upstream or upstream patches - possible removal later
# adding --help option to lpr command
Patch9: cups-lpr-help.patch
# adds logs when job fails due bad conversion
Patch18: cups-filter-debug.patch
# add device id for dymo printer
Patch29: cups-dymo-deviceid.patch

#### UPSTREAM PATCHES ####
# possible security issue - all answers tell to
# possible attacker supported options, which
# can narrow the attack vector - do not send it
# in regular message
Patch40: cups-dont-send-http-options-field.patch

##### Patches removed because IMHO they aren't no longer needed
##### but still I'll leave them in git in case their removal
##### breaks something. 
# every filter and backend should be in /usr/lib/cups, the patch for
# for /usr/lib64/cups is not needed
#Patch6: cups-serverbin-compat.patch
# <sys/socket.h> is included in http-private.h, which is included in 
# cups-private.h and cups-private.h is included in cupsd.h
#Patch10: cups-peercred.patch
# cupsd doesn't save its pid number by default - the patch was introduced for
# initscripts, which are deprecated - I'll remove this patch for now
#Patch11: cups-pid.patch
# enforce ppd line length only when PPD_CONFORM_STRICT is set for old 
# foomatic (from RHEL 3/4)
#Patch14: cups-strict-ppd-line-length.patch
# glibc's getaddrinfo now reacts on changes in /etc/resolv.conf and restarts
# resolver by itself (https://bugzilla.redhat.com/show_bug.cgi?id=1374239)
#Patch17: cups-res_init.patch
# upstream especially doesn't want to use mkstemp because of bad API and 
# portability - because it is patch because of depreacated cups-lpd,
# I remove it because of divergence from upstream
#Patch20: cups-str3382.patch
# now done by configure option
#Patch21: cups-0755.patch
# markes fuzzy device ids - created from mdns message - with FZY, not in upstream
# not clear benefit - removing for now
#Patch23: cups-dnssd-deviceid.patch
# upstream rejected this patch, don't diverge from upstream - when trying to use
# dnssd uri discovered by dnssd backend then printing failed
#Patch27: cups-avahi-address.patch
# seems unnecessary derivation from upstream
#Patch31: cups-no-gcry.patch
# Removing this patch, because we want to default to IPP 2.0, which is needed
# by IPP Everywhere
#Patch33: cups-use-ipp1.1.patch
# rejected by upstream, possibly fixed by str4347.patch according upstream
#Patch34: cups-avahi-no-threaded.patch

# END OF FEDORA PATCHES

### MAGEIA PATCHES ###

#
# Security patches
# P500 -> ...
#
Patch500:       cups-ppdopen-heap-overflow.patch
Patch501:       b018978c278d42c7abf78941251b887c95dfdb07.patch
Patch502:       cups-2.2.11-CVE-2019-8842.patch 
# https://github.com/apple/cups/issues/5530 ( CVE-2019-8696 and CVE-2019-8675 )
Patch503:       a0096a2f730c888c40caa64687319ac8c62c8aff.patch

Patch504:       cups-systemd-fix-mga24189.patch
Patch505:       2a06655e5c1925f09d5a2e38cd073eb1b6f069ad.patch

Patch506:	efbea1742bd30f842fbbfb87a473e5c84f4162f9.patch

Provides:	cupsddk cupsddk-drivers

BuildRequires: pam-devel
BuildRequires: pkgconfig(gnutls)
BuildRequires: libacl-devel
BuildRequires: openldap-devel
BuildRequires: pkgconfig(libusb-1.0)
BuildRequires: pkgconfig(krb5)
BuildRequires: pkgconfig(avahi-client)
BuildRequires: systemd-units
BuildRequires: pkgconfig(systemd)
BuildRequires: pkgconfig(dbus-1)
BuildRequires: automake
# needed for decompressing functions when reading from gzipped ppds
BuildRequires: zlib-devel

# Make sure we get postscriptdriver tags.
%if ! %{with bootstrap}
BuildRequires: python3-cups
%endif

Requires: %{name}-filesystem = %{version}-%{release}
Requires: %{name}-common >= %{version}-%{release}
Requires: hostname
Requires: printer-testpages
# For /usr/share/icons/ to exist and get icons installed
BuildRequires: desktop-common-data
# For desktop menus
Requires: xdg-utils
Recommends: avahi

# Requires /etc/tmpfiles.d (bug #656566)
Requires: systemd-units >= 13
Requires(post): systemd >= %{systemd_required_version}
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

# Make sure we have some filters for converting to raster format.
Requires: cups-filters

%package common
Summary: CUPS printing system - Common stuff
License: GPLv2
Group: System/Printing
Requires: %{libname} >= %{version}-%{release} update-alternatives hostname
# To satisfy LSB/FHS
Provides: lpddaemon

%package -n %{libname}-devel
Summary: CUPS printing system - Development environment "libcups"
License: LGPLv2
Group: Development/C
Requires: libgnutls-devel
Requires: cups-common = %{version}-%{release}
Requires: %{libname} >= %{version}-%{release} 
Requires: gnutls-devel
Provides: libcups-devel = %{version}-%{release}
Provides: libcups2_1-devel = %{version}-%{release}
Obsoletes: cups-devel, libcups1-devel
Provides: cups-devel = %{version}, libcups1-devel = %{version}

%package -n %{libname}
Summary: CUPS printing system - CUPS library
License: LGPLv2
Group: System/Libraries
Requires: hostname
Obsoletes: libcups1
Provides: libcups1 = %{version}

%package filesystem
Summary: CUPS printing system - directory layout
Group: 	 System/Printing
BuildArch: noarch
Conflicts: %{name} < %{version}-%{release}

%description
CUPS printing system provides a portable printing layer for
UNIX® operating systems. It has been developed by Apple Inc.
to promote a standard printing solution for all UNIX vendors and users.
CUPS provides the System V and Berkeley command-line interfaces.
This is the main package needed for CUPS servers (machines where a
printer is connected to or which host a queue for a network
printer). It can also be used on CUPS clients so that they simply pick
up broadcasted printer information from other CUPS servers and do not
need to be assigned to a specific CUPS server by an
%{_sysconfdir}/cups/client.conf file.

%description common
The CUPS printing system provides a portable printing layer for
UNIX® operating systems. It contains the command line utilities for
printing and administration (lpr, lpq, lprm, lpadmin, lpc, ...), man
pages, locales, and a sample configuration file for daemon-less CUPS
clients (%{_sysconfdir}/cups/client.conf).

This package you need for both CUPS clients and servers.

%description -n %{libname}-devel
The CUPS printing system provides a portable printing layer for
UNIX® operating systems. This is the development package for
creating additional printer drivers, printing software, and other CUPS
services using the main CUPS library "libcups".

%description -n %{libname}
The CUPS printing system provides a portable printing layer for
UNIX® operating systems. This package contains the CUPS API library
which contains common functions used by both the CUPS daemon and all
CUPS frontends (lpr-cups, xpp, qtcups, kups, ...).

This package you need for both CUPS clients and servers. It is also
needed by Samba.

%description filesystem
CUPS printing system provides a portable printing layer for
UNIX® operating systems. This package provides some directories which are
required by other packages that add CUPS drivers (i.e. filters, backends etc.).

%prep
%setup -q

# Don't gzip man pages in the Makefile, let rpmbuild do it.
%patch1 -p1 -b .no-gzip-man
# Use the system pam configuration.
%patch2 -p1 -b .system-auth
# Prevent multilib conflict in cups-config script.
%patch3 -p1 -b .multilib
# Ignore rpm save/new files in the banners directory.
%patch5 -p1 -b .banners
# Use compatibility fallback path for ServerBin.
#%%patch6 -p1 -b .serverbin-compat
# Don't export SSLLIBS to cups-config.
%patch7 -p1 -b .no-export-ssllibs
# Allow file-based usb device URIs.
%patch8 -p1 -b .direct-usb
# Add --help option to lpr.
%patch9 -p1 -b .lpr-help
# Fix compilation of peer credentials support.
#%%patch10 -p1 -b .peercred
# Maintain a cupsd.pid file.
#%%patch11 -p1 -b .pid
# Fix implementation of com.redhat.PrinterSpooler D-Bus object.
%patch12 -p1 -b .eggcups
# Increase driverd timeout to 70s to accommodate foomatic (bug #744715).
%patch13 -p1 -b .driverd-timeout
# Only enforce maximum PPD line length when in strict mode.
#%%patch14 -p1 -b .strict-ppd-line-length
# Re-open the log if it has been logrotated under us.
%patch15 -p1 -b .logrotate
# Support for errno==ENOSPACE-based USB paper-out reporting.
%patch16 -p1 -b .usb-paperout
# Re-initialise the resolver on failure in httpAddrGetList() (bug #567353).
#%%patch17 -p1 -b .res_init
# Log extra debugging information if no filters are available.
%patch18 -p1 -b .filter-debug
# Allow the usb backend to understand old-style URI formats.
%patch19 -p1 -b .uri-compat
# Fix temporary filename creation.
#%%patch20 -p1 -b .str3382
# Use mode 0755 for binaries and libraries where appropriate.
#%%patch21 -p1 -b .0755
# Add an SNMP query for HP's device ID OID (STR #3552).
%patch22 -p1 -b .hp-deviceid-oid
# Mark DNS-SD Device IDs that have been guessed at with "FZY:1;".
#%%patch23 -p1 -b .dnssd-deviceid
# Add an SNMP query for Ricoh's device ID OID (STR #3552).
%patch24 -p1 -b .ricoh-deviceid-oid
# Make cups.service Type=notify (bug #1088918).
%patch25 -p1 -b .systemd-socket
# Use IP address when resolving DNSSD URIs (bug #948288).
#%%patch27 -p1 -b .avahi-address
# Added IEEE 1284 Device ID for a Dymo device (bug #747866).
%patch29 -p1 -b .dymo-deviceid
# Use IP_FREEBIND socket option when binding listening sockets (bug #970809).
%patch30 -p1 -b .freebind
# Don't link against libgcrypt needlessly.
#%%patch31 -p1 -b .no-gcry
# Default to IPP/1.1 for now (bug #977813).
#%%patch33 -p1 -b .use-ipp1.1
# Don't use D-Bus from two threads (bug #979748).
#%%patch34 -p1 -b .avahi-no-threaded
# Fixes for jobs with multiple files and multiple formats.
%patch35 -p1 -b .ipp-multifile
# Increase web interface get-devices timeout to 10s (bug #996664).
%patch36 -p1 -b .web-devices-timeout
# Set the default for SyncOnClose to Yes.
%patch37 -p1 -b .synconclose
# CUPS may fail to start if NIS groups are used (bug #1494558)
%patch38 -p1 -b .ypbind
# Add failover backend (bug #1689209)
%patch39 -p1 -b .failover

%patch500 -p1
%patch502 -p1
%patch504 -p1
%patch505 -p1

%patch506 -p1

%if %{lspp}
# LSPP support.
%patch100 -p1 -b .lspp
%endif

#### UPSTREAMED PATCHES ####
%patch40 -p1 -b .dont-send-http-options-field

# Let local printers be broadcasted in the local network(s)
perl -p -i -e 's:(Listen\s+)localhost:$1*:' conf/cupsd.conf.in
perl -p -i -e 's:(Browsing\s+On):$1:' conf/cupsd.conf.in
perl -p -i -e 's:(<Location\s+/\s*>):$1\n  Allow \@LOCAL:' conf/cupsd.conf.in

# Allow remote administration in local network (connections are encrypted,
# so no security problem)
perl -p -i -e 's:(<Location\s+/admin(|/conf)\s*>):$1\n  Allow \@LOCAL:' conf/cupsd.conf.in

# Let the Makefiles not trying to set file ownerships
perl -p -i -e "s/ -o \\$.CUPS_USER.//" scheduler/Makefile
perl -p -i -e "s/ -g \\$.CUPS_GROUP.//" scheduler/Makefile
perl -p -i -e "s/ -o \\$.CUPS_USER.//" systemv/Makefile
perl -p -i -e "s/ -g \\$.CUPS_GROUP.//" systemv/Makefile

# Log to the system journal by default (bug #1078781, bug #1519331).
sed -i -e 's,^ErrorLog .*$,ErrorLog syslog,' conf/cups-files.conf.in
sed -i -e 's,^AccessLog .*$,AccessLog syslog,' conf/cups-files.conf.in
sed -i -e 's,^PageLog .*,PageLog syslog,' conf/cups-files.conf.in

# Add comment text mentioning syslog is systemd journal (bug #1358589)
sed -i -e 's,\"syslog\",\"syslog\" \(syslog means systemd journal by default\),' conf/cups-files.conf.in

# Add group wheel to SystemGroups (bug #1405669)
sed -i -e 's,^SystemGroup .*$, SystemGroup sys root wheel,' conf/cups-files.conf.in

# Let's look at the compilation command lines.
perl -pi -e "s,^.SILENT:,," Makedefs.in

# Load nprint backend
cp %{SOURCE11} nprint
# Load the "photo_print" utility
cp %{SOURCE14} photo_print
# Load the "cjktexttops" filter
cp %{SOURCE16} cjktexttops

f=CREDITS.md
mv "$f" "$f"~
iconv -f MACINTOSH -t UTF-8 "$f"~ > "$f"
rm -f "$f"~

# the "--with-docdir" option has to be given because the default setting is broken
aclocal -I config-scripts
autoconf -f -I config-scripts

%build
%serverbuild
# for the PHP module
%define _disable_ld_no_undefined 1
%setup_compile_flags
# cups can use different compiler if it is installed, so set to GCC for to be sure
export CC=gcc
export CXX=g++
# cups uses $DSOFLAGS instead of $LDFLAGS for shared libs
export DSOFLAGS="$LDFLAGS"
# --enable-debug to avoid stripping binaries
%configure --with-docdir=%{_datadir}/%{name}/www --enable-debug \
%if %{lspp}
	--enable-lspp \
%endif
	--with-exe-file-perm=0755 \
	--with-cupsd-file-perm=0755 \
	--with-log-file-perm=0600 \
	--enable-relro \
	--with-dbusdir=%{_sysconfdir}/dbus-1 \
	--with-php=/usr/bin/php-cgi \
	--enable-avahi \
	--enable-threads \
	--enable-gnutls \
	--enable-webif \
	--with-xinetd=no \
	--with-access-log-level=actions \
	--enable-page-logging \
	localedir=%{_datadir}/locale

%make


%install
make BUILDROOT=%{buildroot} install 

rm -rf	%{buildroot}%{_initddir} \
	%{buildroot}%{_sysconfdir}/init.d \
	%{buildroot}%{_sysconfdir}/rc?.d
mkdir -p %{buildroot}%{_unitdir}
find %{buildroot}%{_datadir}/cups/model -name "*.ppd" |xargs gzip -n9f

%if %{use_alternatives}
pushd %{buildroot}%{_bindir}
for i in cancel lp lpq lpr lprm lpstat; do
	mv $i $i.cups
done
cd %{buildroot}%{_sbindir}
mv lpc lpc.cups
cd %{buildroot}%{_mandir}/man1
for i in cancel lp lpq lpr lprm lpstat; do
	mv $i.1 $i-cups.1
done
cd %{buildroot}%{_mandir}/man8
mv lpc.8 lpc-cups.8
popd
%endif

# Install nprint backend
install -m 755 nprint %{buildroot}%{cups_serverbin}/backend/

# Link dnssd backend as mdns backend
(cd %{buildroot}%{cups_serverbin}/backend && ln -s dnssd mdns)

# Install "photo_print"
install -m 755 photo_print %{buildroot}%{_bindir}

# Install "cjktexttops"
install -m 755 cjktexttops %{buildroot}%{cups_serverbin}/filter/

ln -s %{_datadir}/printer-testpages/testprint.ps %{buildroot}%{_datadir}/cups/data/testprint-mga.ps

# Install startup script
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE18} %{buildroot}%{_sysconfdir}/sysconfig/cups
install -d %{buildroot}%{_sysconfdir}/modprobe.d

# Install script for automatic CUPS configuration
cp %{SOURCE15} %{buildroot}%{_sbindir}/correctcupsconfig
chmod a+rx %{buildroot}%{_sbindir}/correctcupsconfig

%ifarch x86_64
# This one will be removed soon, when all other packages are
# modified appropriately
ln -s %{cups_serverbin} %{buildroot}%{_libdir}/cups
%endif

# Install missing headers (Thanks to Oden Eriksson)
install -m644 cups/debug-private.h  %{buildroot}%{_includedir}/cups/
install -m644 cups/string-private.h %{buildroot}%{_includedir}/cups/
install -m644 config.h %{buildroot}%{_includedir}/cups/

# Multiarch fixes
%multiarch_includes %{buildroot}%{_includedir}/cups/config.h

mv %{buildroot}%{_unitdir}/org.cups.cupsd.path %{buildroot}%{_unitdir}/cups.path
mv %{buildroot}%{_unitdir}/org.cups.cupsd.service %{buildroot}%{_unitdir}/cups.service
mv %{buildroot}%{_unitdir}/org.cups.cupsd.socket %{buildroot}%{_unitdir}/cups.socket
mv %{buildroot}%{_unitdir}/org.cups.cups-lpd.socket %{buildroot}%{_unitdir}/cups-lpd.socket
mv %{buildroot}%{_unitdir}/org.cups.cups-lpd@.service %{buildroot}%{_unitdir}/cups-lpd@.service
/bin/sed -i -e "s,org.cups.cupsd,cups,g" %{buildroot}%{_unitdir}/cups.service

mkdir -p %{buildroot}%{_datadir}/pixmaps %{buildroot}%{_sysconfdir}/X11/sysconfig %{buildroot}%{_sysconfdir}/X11/applnk/System %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/cups
install -p -m 755 %{SOURCE7} %{buildroot}%{cups_serverbin}/backend/ncp

# Ship an rpm macro for where to put driver executables.
mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -m 0644 %{SOURCE8} %{buildroot}%{_rpmconfigdir}/macros.d

# Create dummy config files /etc/cups/printers.conf,
# /etc/cups/classes.conf, and /etc/cups/client.conf
touch %{buildroot}%{_sysconfdir}/cups/printers.conf
touch %{buildroot}%{_sysconfdir}/cups/classes.conf
touch %{buildroot}%{_sysconfdir}/cups/client.conf

# Remove links to the startup script, we make our own ones with chkconfig
rm -rf %{buildroot}%{_sysconfdir}/rc?.d/[SK]*
# Remove unshipped files.
rm -rf %{buildroot}%{_mandir}/cat? %{buildroot}%{_mandir}/*/cat?
# there are pdf-banners shipped with cups-filters (#919489)
rm -rf %{buildroot}%{_datadir}/cups/banners
rm -f %{buildroot}%{_datadir}/cups/data/testprint

# install /usr/lib/tmpfiles.d/cups.conf (bug #656566, bug #893834)
mkdir -p ${RPM_BUILD_ROOT}%{_tmpfilesdir}
cat > ${RPM_BUILD_ROOT}%{_tmpfilesdir}/cups.conf <<EOF
# This file is part of cups.
#
# See tmpfiles.d(5) for details

d /run/cups 0755 root lp -
d /run/cups/certs 0511 lp sys -

d /var/spool/cups/tmp - - - 30d
EOF

# /usr/lib/tmpfiles.d/cups-lp.conf (bug #812641)
cat > ${RPM_BUILD_ROOT}%{_tmpfilesdir}/cups-lp.conf <<EOF
# Legacy parallel port character device nodes, to trigger the
# auto-loading of the kernel module on access.
#
# See tmpfiles.d(5) for details

c /dev/lp0 0660 root lp - 6:0
c /dev/lp1 0660 root lp - 6:1
c /dev/lp2 0660 root lp - 6:2
c /dev/lp3 0660 root lp - 6:3
EOF

# Prefer xdg-utils than htmlview (kde one)
sed -i s/htmlview/xdg-open/ %{buildroot}%{_datadir}/applications/*.desktop

# http://qa.mandriva.com/show_bug.cgi?id=28383
# Common PPD dirs
mkdir -p %{buildroot}%{_datadir}/ppd

# Make CUPS know them
ln -s /usr/local/share/ppd %{buildroot}%{_datadir}/cups/model/1-local-admin
ln -s /opt/share/ppd %{buildroot}%{_datadir}/cups/model/2-third-party
ln -s %{_datadir}/ppd %{buildroot}%{_datadir}/cups/model/3-distribution

# Common printer driver dirs
mkdir -p %{buildroot}%{_libdir}/printdriver
# Other dirs can't be handled here, but on %post instead.

%pre
%ifarch x86_64
# Fix /usr/lib/cups directory, so that updates can be done
if [ -d %{_libdir}/cups ] && ! [ -h %{_libdir}/cups ]; then
    if [ -h %{cups_serverbin} ] || ! [ -e %{cups_serverbin} ]; then
        rm -f %{cups_serverbin}
        mv %{_libdir}/cups %{cups_serverbin}
    else
        rm -rf %{_libdir}/cups.rpmsave
        mv %{_libdir}/cups %{_libdir}/cups.rpmsave
        #echo 'Moved %{_libdir}/cups to %{_libdir}/cups.rpmsave' 1>&2
    fi
fi
%endif

%post
%_tmpfilescreate %{name}
%_tmpfilescreate %{name}-lp

# We can't enforce this. Bug #35993
for d in /opt/share/ppd /opt/lib/printdriver /usr/local/share/ppd /usr/local/lib/printdriver
do
  [ ! -e $d ] && mkdir -p $d || :
done
# End of 28383

# Previous migration script unnecessarily put PageLogFormat into cups-files.conf
# (see bug #1148995)
FILE=%{_sysconfdir}/cups/cups-files.conf
for keyword in PageLogFormat; do
    /bin/sed -i -e "s,^$keyword,#$keyword,i" "$FILE" || :
done

# Because of moving logs to journal, we need to create placeholder files
# at /var/log/cups for users, whose are going to install CUPS on new OS
# machine with info message
%if 0%{?mageia}
confignames=( "ErrorLog" "AccessLog" "PageLog" )
lognames=( "error_log" "access_log" "page_log" )
message="This CUPS log has been moved into journal by default unless changes have been made in /etc/cups/cups-files.conf. Log messages can be got by \"$ journalctl -u cups -e\""
for ((i=0;i<${#confignames[@]};i++));
do
  found=`%{_bindir}/grep -i "${confignames[i]} syslog" /etc/cups/cups-files.conf`
  if [ ! -z "$found" ]
  then
    if [ ! -f %{_localstatedir}/log/cups/${lognames[i]} ]
    then
      %{_bindir}/touch %{_localstatedir}/log/cups/${lognames[i]} || :
    fi
    perms=`%{_bindir}/ls -lah %{_localstatedir}/log/cups/${lognames[i]} | %{_bindir}/grep -v -e "\-rw-------" -e "root lp"`
    if [ ! -z "$perms" ]
    then
      # we need to set correct permissions and ownership because of possible
      # security issues
      # we need to have it here, because previous CUPS releases had the bug.
      # Checking permissions and ownership here fixes it.
      %{_bindir}/chown root:lp %{_localstatedir}/log/cups/${lognames[i]} || :
      %{_bindir}/chmod 600 %{_localstatedir}/log/cups/${lognames[i]} || :
    fi
    lastmessage=`%{_bindir}/tail -n 1 %{_localstatedir}/log/cups/${lognames[i]} | %{_bindir}/grep "$message"`
    if [ -z "$lastmessage" ]
    then
      %{_bindir}/echo $message >> %{_localstatedir}/log/cups/${lognames[i]} || :
    fi
  fi
done
%endif

# Let CUPS daemon be automatically started at boot time
%_post_service cups
#_post_service cups-lpd

%preun
# Let CUPS daemon not be automatically started at boot time any more
%_preun_service cups
#_preun_service cups-lpd

%postun
%_postun_groupdel lpadmin
#_postun_service cups-lpd

%post common
# Set up update-alternatives entries
%if %{use_alternatives}
/usr/sbin/alternatives --install %{_bindir}/lpr print %{_bindir}/lpr.cups 40 \
	 --slave %{_bindir}/lp print-lp %{_bindir}/lp.cups \
	 --slave %{_bindir}/lpq print-lpq %{_bindir}/lpq.cups \
	 --slave %{_bindir}/lprm print-lprm %{_bindir}/lprm.cups \
	 --slave %{_bindir}/lpstat print-lpstat %{_bindir}/lpstat.cups \
	 --slave %{_bindir}/cancel print-cancel %{_bindir}/cancel.cups \
	 --slave %{_sbindir}/lpc print-lpc %{_sbindir}/lpc.cups \
	 --slave %{_mandir}/man1/cancel.1.gz print-cancelman %{_mandir}/man1/cancel-cups.1.xz \
	 --slave %{_mandir}/man1/lp.1.gz print-lpman %{_mandir}/man1/lp-cups.1.xz \
	 --slave %{_mandir}/man8/lpc.8.gz print-lpcman %{_mandir}/man8/lpc-cups.8.xz \
	 --slave %{_mandir}/man1/lpq.1.gz print-lpqman %{_mandir}/man1/lpq-cups.1.xz \
	 --slave %{_mandir}/man1/lpr.1.gz print-lprman %{_mandir}/man1/lpr-cups.1.xz \
	 --slave %{_mandir}/man1/lprm.1.gz print-lprmman %{_mandir}/man1/lprm-cups.1.xz \
	 --slave %{_mandir}/man1/lpstat.1.gz print-lpstatman %{_mandir}/man1/lpstat-cups.1.xz
%endif
exit 0

%preun common
%if %{use_alternatives}
if [ $1 -eq 0 ] ; then
	/usr/sbin/alternatives --remove print %{_bindir}/lpr.cups
fi
%endif
exit 0

%files
%doc README.md CREDITS.md CHANGES.md
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/cupsd.conf
%config(noreplace) %attr(-,root,root) %{_sysconfdir}/sysconfig/cups
%ghost %config(noreplace) %{_sysconfdir}/cups/printers.conf
%ghost %config(noreplace) %{_sysconfdir}/cups/classes.conf
%attr(-,root,sys) %{_sysconfdir}/cups/cupsd.conf.default
%verify(not md5 size mtime) %config(noreplace) %attr(0640,root,lp) %{_sysconfdir}/cups/cups-files.conf
%attr(0640,root,lp) %{_sysconfdir}/cups/cups-files.conf.default
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/ppd
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/ssl
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/cups/snmp.conf
%attr(0640,root,lp) %{_sysconfdir}/cups/snmp.conf.default
%config(noreplace) %attr(-,root,sys) %{_sysconfdir}/dbus*/system.d/cups.conf
%{_tmpfilesdir}/cups.conf
%{_tmpfilesdir}/cups-lp.conf
%dir %{_datadir}/%{name}/www
%dir %{_datadir}/%{name}/www/de
%dir %{_datadir}/%{name}/www/es
%dir %{_datadir}/%{name}/www/ja
%dir %{_datadir}/%{name}/www/ru
%{_datadir}/%{name}/www/images
%{_datadir}/%{name}/www/*.css
# 1658673 - html files cannot be docs, because CUPS web ui will not have
# introduction page on Fedora Docker image (because rpms are installed
# without docs there because of space reasons)
%{_datadir}/%{name}/www/index.html
%{_datadir}/%{name}/www/help
%{_datadir}/%{name}/www/robots.txt
%{_datadir}/%{name}/www/de/index.html
%{_datadir}/%{name}/www/es/index.html
%{_datadir}/%{name}/www/ja/index.html
%{_datadir}/%{name}/www/ru/index.html
%{_datadir}/%{name}/www/pt_BR/index.html
%{_datadir}/%{name}/www/apple-touch-icon.png
%dir %{_datadir}/%{name}/usb
%{_datadir}/%{name}/usb/org.cups.usb-quirks
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.socket
%{_unitdir}/%{name}.path
%config(noreplace) %{_sysconfdir}/pam.d/cups
%config(noreplace) %{_sysconfdir}/logrotate.d/cups
%{cups_serverbin}/cgi-bin
%{cups_serverbin}/daemon
%{cups_serverbin}/notifier
%{cups_serverbin}/filter/*
%{cups_serverbin}/monitor
%{cups_serverbin}/backend/*
%{_datadir}/cups/ipptool
%{_datadir}/cups/drv/sample.drv
%{_datadir}/cups/examples
%{_datadir}/cups/mime/mime.types
%{_datadir}/cups/mime/mime.convs
%{_datadir}/cups/ppdc/*.defs
%{_datadir}/cups/ppdc/*.h
%{_datadir}/cups/templates
%{_datadir}/cups/data
%exclude %{_datadir}/cups/doc
%{_datadir}/cups/model
%{_datadir}/cups/profiles
%attr(0755,root,sys) %{_var}/log/cups
# Set ownerships of spool directory which is normally done by 'make install'
# Because RPM does 'make install' as normal user, this has to be done here
%dir %attr(0710,root,sys) %{_var}/spool/cups
%dir %attr(01770,root,sys) %{_var}/spool/cups/tmp
%dir %attr(775,root,sys) %{_var}/cache/cups
# Bug #28383 dirs
%dir %{_libdir}/printdriver
# Desktop menu and icons
%{_datadir}/applications/*
%{_iconsdir}/hicolor/*/apps/%{name}.png
%ifarch x86_64
# Compatibility link, will be removed soon
%{_libdir}/cups
%endif
%{_unitdir}/cups-lpd.socket
%{_unitdir}/cups-lpd@.service

%files common
%dir %config(noreplace) %attr(-,lp,sys) %{_sysconfdir}/cups
%ghost %config(noreplace) %attr(-,lp,sys) %{_sysconfdir}/cups/client.conf
%{_sbindir}/*
%{_bindir}/*cups
%{_bindir}/ipptool
%{_bindir}/ippfind
%{_bindir}/lpoptions
%{_bindir}/photo_print
%{_bindir}/ppdc
%{_bindir}/ppdhtml
%{_bindir}/ppdi
%{_bindir}/ppdmerge
%{_bindir}/ppdpo
%{_bindir}/cupstestppd
%{_bindir}/cupstestdsc
%{_mandir}/man?/*
# (akien) Those are actually needed for translation (mga#16321)
%lang(ca) %{_datadir}/locale/ca/cups_ca.po
%lang(cs) %{_datadir}/locale/cs/cups_cs.po
%lang(de) %{_datadir}/locale/de/cups_de.po
%lang(es) %{_datadir}/locale/es/cups_es.po
%lang(fr) %{_datadir}/locale/fr/cups_fr.po
%lang(it) %{_datadir}/locale/it/cups_it.po
%lang(ja) %{_datadir}/locale/ja/cups_ja.po
%lang(pt) %{_datadir}/locale/pt_BR/cups_pt_BR.po
%lang(ru) %{_datadir}/locale/ru/cups_ru.po
%lang(zh_CN) %{_datadir}/locale/zh_CN/cups_zh_CN.po

%files -n %{libname}
%{_libdir}/*.so.*

%files filesystem
%dir %{cups_serverbin}
%dir %{cups_serverbin}/backend
%dir %{cups_serverbin}/driver
%dir %{cups_serverbin}/filter
%dir %{_datadir}/cups
%dir %{_datadir}/cups/data
%dir %{_datadir}/cups/drv
%dir %{_datadir}/cups/mime
%dir %{_datadir}/cups/model
%dir %{_datadir}/cups/ppdc
%dir %{_datadir}/ppd

%files -n %{libname}-devel
%{_bindir}/cups-config
%{_libdir}/*.so
%{_includedir}/cups/*
%multiarch %{multiarch_includedir}/cups/*
%{_rpmconfigdir}/macros.d/macros.cups


%changelog
* Thu Mar 04 2021 neoclust <neoclust> 2.2.13-1.5.mga7
+ Revision: 1698141
- Add P506: Fixes CVE-2020-10001 (mga#28277)
- Really apply P505
- Add P504 to fix regressions with some ppd ( mga#26770)
- New version 2.2.13
- Add P503 to fix CVE-2019-8696 and CVE-2019-8675 (mga#26531)
- Add Patches to fix CVE-2019-8842 and CVE-2019-2228
- Add P500: Fix CVE-2020-3898
+ zezinho <zezinho>
- workaround mga#24189

* Wed May 01 2019 tv <tv> 2.2.11-2.mga7
+ Revision: 1396080
- Stop advertising the HTTP methods that are supported (rhbz#1700664)
- Stop advertising the HTTP methods that are supported (rhbz#1700664)

* Wed Mar 27 2019 tv <tv> 2.2.11-1.mga7
+ Revision: 1380551
- 2.2.11
- Add failover backend (rhbz#1689209)
- automake sometimes fails to generate correct macros - so force it
- cups fails to build if clang is installed (rhbz#1672715)

* Sat Jan 12 2019 tv <tv> 2.2.10-1.mga7
+ Revision: 1355699
- new release

* Mon Dec 17 2018 tv <tv> 2.2.8-3.mga7
+ Revision: 1342265
- remake of rhbz#1499261 (Move log files into journal)
- Main index.html of web interface doesn't get installed when not installing documentation (rhbz#1658673)
- Predictable session cookie breaks CSRF protection [fedora-all] (CVE-2018-4700 rhbz#1657750)

* Sun Nov 18 2018 tv <tv> 2.2.8-2.mga7
+ Revision: 1330652
- Jobs with multiple files don't complete when backend fails (rhbz#1622432)

* Wed Oct 03 2018 tv <tv> 2.2.8-1.mga7
+ Revision: 1316157
- 2.2.8, removing several downstream patches, adding some upstream patches
- correcting license
- fixed coverity issues
- Make cups systemd unit files more upstream-like (rhbz#1618018)
- cupsd LogLevel ignored when logging to journald (syslog) (rhbz#1589593)
- cups-driverd doesn't recognize static gzipped ppds (rhbz#1590123)
- rebase to 2.2.7
- substitute default values for invalid job attributes (upstream issues #5229 and #5186)
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Tue Apr 03 2018 tv <tv> 2.2.6-2.mga7
+ Revision: 1214918
- temporary disable patch 40
- drop obsolete AppleTalk/netatalk backend
- Move log files into journal (rhbz#1499261)
- Fix for CVE-2017-18248
- Use dbus fix instead of general attr delete (upstream)

* Mon Nov 06 2017 tv <tv> 2.2.6-1.mga7
+ Revision: 1176110
- new release

* Wed Oct 18 2017 tv <tv> 2.2.5-1.mga7
+ Revision: 1172454
- new release

* Wed Oct 04 2017 tv <tv> 2.2.4-5.mga7
+ Revision: 1168809
- Cannot browse CUPS servers in GNOME Control Panel Printers (rhbz#1498091)
- Can not get destinations from CUPS server (rhbz#1484916)

* Wed Sep 27 2017 tv <tv> 2.2.4-3.mga7
+ Revision: 1160138
- CUPS may fail to start if NIS groups are used (rhbz#1494558)

* Wed Aug 09 2017 joequant <joequant> 2.2.4-2.mga7
+ Revision: 1139460
- fix major bug that causes printers not to get shown in libreoffice
  and KDE.  See https://bugs.archlinux.org/task/54695

* Mon Jul 17 2017 tv <tv> 2.2.4-1.mga7
+ Revision: 1124071
- package zh_CN translation
- rebase to 2.2.4 (mga#21168)
- sync patches with FC
- adding group wheel to SystemGroup (rhbz#1405669)

* Fri May 26 2017 neoclust <neoclust> 2.2.3-2.mga6
+ Revision: 1104819
- Rebuild to see if it help to fix a crash

* Wed Mar 29 2017 luigiwalser <luigiwalser> 2.2.3-1.mga6
+ Revision: 1095169
- 2.2.3

* Mon Mar 27 2017 luigiwalser <luigiwalser> 2.2.2-1.mga6
+ Revision: 1094913
- 2.2.2
- sync patch changes with fedora

* Thu Dec 01 2016 tv <tv> 2.2.1-1.mga6
+ Revision: 1071394
- new release
- Unable to print from Windows (7) on a Cups-Server with german umlauts in the filename (rhbz#1386751)
- (cups-usb-quirks) usb printer doesn't print (usblp0: USB Bidirectional printer dev) (#873123)

* Fri Sep 30 2016 tv <tv> 2.2.0-3.mga6
+ Revision: 1057856
- fixing looping in partial failing service (bug #1366775)

* Wed Sep 21 2016 pterjan <pterjan> 2.2.0-2.mga6
+ Revision: 1054997
- Fix manpage extension in alternatives, this should be made more robust

* Thu Sep 15 2016 tv <tv> 2.2.0-1.mga6
+ Revision: 1053128
- new version

* Fri Jun 17 2016 tv <tv> 2.1.4-1.mga6
+ Revision: 1021975
- new release

* Tue Jun 07 2016 tv <tv> 2.1.3-3.mga6
+ Revision: 1020634
- adjust BRs for latest systemd

* Sun Apr 10 2016 blino <blino> 2.1.3-2.mga6
+ Revision: 1000167
- drop poppler requires, pdftops was required by filters which have been split out in 1.6

* Mon Feb 08 2016 tv <tv> 2.1.3-1.mga6
+ Revision: 950444
- 2.1.3

* Mon Jan 11 2016 luigiwalser <luigiwalser> 2.1.2-2.mga6
+ Revision: 921799
- rebuild for gnutls

* Mon Dec 07 2015 tv <tv> 2.1.2-1.mga6
+ Revision: 908714
- new release
- new release

* Tue Dec 01 2015 tv <tv> 2.1.1-1.mga6
+ Revision: 907521
- adjust file list
- drop merged patch
- drop merged patch
- new release
- notice that this package is synced with FC

* Thu Oct 29 2015 doktor5000 <doktor5000> 2.1.0-3.mga6
+ Revision: 896420
- added upstream fix for cups STR#4725
  o fixes issues with non-world-readable PPD files for ipp:// printers
+ akien <akien>
- Repackage mistakenly removed translation po files (mga#16321)

* Sun Sep 13 2015 blino <blino> 2.1.0-2.mga6
+ Revision: 878875
- allow to skip python-cups buildrequire for bootstrap
- package cups icons (buildrequire desktop-common-data to get them installed)

* Wed Sep 02 2015 tv <tv> 2.1.0-1.mga6
+ Revision: 872266
- new release
- new release

* Sat Aug 29 2015 tv <tv> 2.0.4-2.mga6
+ Revision: 870782
- ship macros.cups from FC (needed for new cups-filters)

* Sat Aug 29 2015 tv <tv> 2.0.4-1.mga6
+ Revision: 870765
- new release

* Tue Aug 25 2015 pterjan <pterjan> 2.0.3-7.mga6
+ Revision: 869216
- Rebuild with gcc 5

* Fri Aug 21 2015 tmb <tmb> 2.0.3-6.mga6
+ Revision: 867560
- rebuild for new gcc

* Sun Jul 26 2015 tv <tv> 2.0.3-5.mga6
+ Revision: 857751
- drop old conflicts on cupsddk

* Sat Jul 25 2015 tv <tv> 2.0.3-4.mga6
+ Revision: 857624
- remove obsolete BRs
- fixed CREDITS.txt character encoding
- fix "WARNING: unrecognized options: --with-pdftops"
- reorder some requires (reduce diff with FC)
- BR python-cups in order to get postscriptdriver tags
- stop advertizing cups-1.1 vs cups-1.4
- kill poll_ppd_base (do not build for 2 years)
- further simplify
- simplify

* Fri Jul 03 2015 tv <tv> 2.0.3-3.mga6
+ Revision: 849668
- fix upgrade

* Fri Jul 03 2015 tv <tv> 2.0.3-2.mga6
+ Revision: 849635
- fix slow resume of jobs after restart (STR #4646)
- fix redirection from CGI scripts (rhbz#1232030, STR #4538)
- also trigger cups-lp.conf
- move doc in %%_datadir/cups/www (reduce diff with FC)
- add configure options from FC
- try running as group 'lp' instead of 'sys'
- reduce diff with FC (s/buildroot/RPM_BUILD_ROOT/, bug ref, ..)
- compress PDD
- sync alternatives with FC (less diff)
- kill old mdv build workaround
- kill alternatives for accept/reject/disable (mga#11008)

* Sat Jun 20 2015 tv <tv> 2.0.3-1.mga6
+ Revision: 835803
- 2.0.3
- remove upstreamed patches

* Wed Jun 10 2015 luigiwalser <luigiwalser> 2.0.2-5.mga5
+ Revision: 822968
- add upstream patches to fix two security issues fixed in 2.0.3:
  - STR#4609 (CVE-2015-1158 and CVE-2015-1159)
  - STR#4602
- update cups-lspp.patch (from fedora)

* Fri May 01 2015 tv <tv> 2.0.2-4.mga5
+ Revision: 820955
- bump release for core/release

* Tue Mar 17 2015 tv <tv> 2.0.2-3.mga5
+ Revision: 818707
- Avoid busy loop in cupsd when connection is closed after request
  sent (rhbz#1179596).

* Fri Feb 20 2015 tv <tv> 2.0.2-2.mga5
+ Revision: 816080
- Fixed multilib.patch to check for gnutls instead of openssl (from FC)

* Wed Feb 11 2015 tv <tv> 2.0.2-1.mga5
+ Revision: 814731
- new release

* Sun Feb 01 2015 tv <tv> 2.0.1-3.mga5
+ Revision: 812964
- fix systemd notify support (rhbz#1184453)

* Mon Jan 05 2015 shlomif <shlomif> 2.0.1-2.mga5
+ Revision: 808632
- Don't Add BrowseAddress which is invalid cups conf syntax (MGA #14952).
  Thanks to Richard Houser, who is my apprentice.

* Sun Nov 16 2014 tv <tv> 2.0.1-1.mga5
+ Revision: 797556
- 2.0.1
- sync with FC:
  o Re-introduce SSLOptions configuration directive, disable SSL3 by
    default (STR #4476).
  o Enable SSL again via GnuTLS (bug #1161235).
  o Removed openssl requirements from spec file as it is no longer
    supported upstream (see bug #1161235).
  o New systemd journal fields CUPS_DEST and CUPS_PRINTER, as well as
    accurate code location fields.

* Thu Nov 13 2014 tv <tv> 2.0.0-2.mga5
+ Revision: 796857
- rebuild for core/release

* Thu Oct 23 2014 tv <tv> 2.0.0-1.mga5
+ Revision: 792587
- new release
- drop merged patch

* Wed Oct 15 2014 umeabot <umeabot> 1.7.5-9.mga5
+ Revision: 741526
- Second Mageia 5 Mass Rebuild

* Fri Oct 03 2014 luigiwalser <luigiwalser> 1.7.5-8.mga5
+ Revision: 736484
- sync patches with fedora (update str#4461 patch from upstream and add str#4475)

* Thu Sep 18 2014 umeabot <umeabot> 1.7.5-7.mga5
+ Revision: 693708
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.7.5-6.mga5
+ Revision: 678618
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Tue Sep 09 2014 luigiwalser <luigiwalser> 1.7.5-5.mga5
+ Revision: 673880
- no longer requires net-tools (only uses commands from hostname package)

* Tue Sep 09 2014 luigiwalser <luigiwalser> 1.7.5-4.mga5
+ Revision: 673844
- add requires on hostname now that it is in a different package

* Thu Sep 04 2014 joequant <joequant> 1.7.5-3.mga5
+ Revision: 671740
- update to new systemd

* Sat Aug 30 2014 tv <tv> 1.7.5-2.mga5
+ Revision: 669522
- sync patches with FC:
  o Use upstream patch for STR #4461.
  o Upstream patch for STR #4396, pre-requisite for STR #2913 patch.
  o Upstream patch for STR #2913 to limit Get-Jobs replies to 500 jobs
    (bug #421671).
  o Fix conf/log file reading for authenticated users (STR #4461).

* Fri Aug 01 2014 tv <tv> 1.7.5-1.mga5
+ Revision: 658892
- new release

* Thu Jul 31 2014 tv <tv> 1.7.4-4.mga5
+ Revision: 658391
- we use FC patches

* Wed Jul 30 2014 luigiwalser <luigiwalser> 1.7.4-3.mga5
+ Revision: 658341
+ rebuild (emptylog)

* Wed Jul 30 2014 luigiwalser <luigiwalser> 1.7.4-2.mga5
+ Revision: 658337
- add upstream patch via debian to fix issue with cgi scripts (str#4454)
- add upstream patch via debian to fix CVE-2014-5029/CVE-2014-503[01]

* Thu Jul 17 2014 tv <tv> 1.7.4-1.mga5
+ Revision: 653503
- new release

* Wed May 28 2014 fwang <fwang> 1.7.3-1.mga5
+ Revision: 627126
- 1.7.3

* Mon Apr 28 2014 tv <tv> 1.7.2-1.mga5
+ Revision: 618755
- 1.7.2
- sync patches with F
- 1.7.2
- sync patches with F

* Tue Apr 22 2014 luigiwalser <luigiwalser> 1.7.1-3.mga5
+ Revision: 617401
- add patch from upstream via fedora to fix CVE-2014-2856

* Wed Mar 19 2014 dglent <dglent> 1.7.1-2.mga5
+ Revision: 605545
- Remove trailing whitespaces
- Find and remove sources translation files
- Dont install source translation files

* Fri Feb 07 2014 tv <tv> 1.7.1-1.mga5
+ Revision: 584969
- new release
- sync patches with RH

* Tue Jan 28 2014 colin <colin> 1.7.0-7.mga4
+ Revision: 568517
- Revert back to dnssd as CUPS support has been removed
- Address slow shutdown issues by updating avahi patch from Fedora rhbz#1044602

* Mon Jan 27 2014 colin <colin> 1.7.0-6.mga4
+ Revision: 568452
- Do not 'fix' configure as it will be rebuilt anyway.
+ neoclust <neoclust>
- Use cups as default BrowseLocalProtocols

* Thu Jan 16 2014 oden <oden> 1.7.0-5.mga4
+ Revision: 566695
- P48: security fix for CVE-2013-6891

* Tue Nov 19 2013 tv <tv> 1.7.0-4.mga4
+ Revision: 551861
- avoid stale lockfile in dbus notifier (rhbz#1026949)
- use upstream patch for stringpool corruption issue (rhbz#974048)
- adjusted commented out default for SyncOnClose in cups-files.conf
- set the default for SyncOnClose to Yes

* Sun Nov 17 2013 blino <blino> 1.7.0-3.mga4
+ Revision: 551696
- install lp user fix udev rule after 73-seat-late.rules since the uaccess helper resets ACLs (#10985)
- run udev lp user fix on normal device, not parent (#10985), and merge with parport rule
- run udev lp user fix for bus/usb device too, not just usb/lp0 (#10985)
- add back udev rule to fix perms of USB devices for cups helpers like hplip (#10985)

* Wed Oct 30 2013 tv <tv> 1.7.0-2.mga4
+ Revision: 548016
- use upstream patch to fix job history

* Sun Oct 27 2013 colin <colin> 1.7.0-1.mga4
+ Revision: 547385
- Add Italian po file
+ fwang <fwang>
- fix str fmt
+ tv <tv>
- new release
- fix job history logging
- allow "journal" log type for log output to system journal

* Mon Oct 21 2013 umeabot <umeabot> 1.7-0.rc1.9.mga4
+ Revision: 538888
- Mageia 4 Mass Rebuild

* Thu Oct 03 2013 tv <tv> 1.7-0.rc1.8.mga4
+ Revision: 490874
- sync with FC:
  o revert upstream change to FINAL_CONTENT_TYPE in order to fix printing to
    remote CUPS servers (rhbz#1010580)
  o add SyncOnClose option (rhbz#984883)

* Wed Aug 21 2013 tv <tv> 1.7-0.rc1.7.mga4
+ Revision: 468988
- sync with FC:
  o increase web interface get-devices timeout to 10s (rhbz#996664)
  o build with full read-only relocations (rhbz#996740)
  o fixes for jobs with multiple files and multiple formats
  o fixed cups-config, broken by last change (rhbz#987660)
- do not force cups to run as lp:sys & drop udev rules (mga#10985)

* Mon Jul 29 2013 blino <blino> 1.7-0.rc1.6.mga4
+ Revision: 460402
- require acl since setfacl is used by 69-printers_lp_user_fix.rules (#10475)

* Fri Jul 26 2013 tv <tv> 1.7-0.rc1.5.mga4
+ Revision: 458363
- sync patches with RH (reverting unix2dos)

* Tue Jul 23 2013 joequant <joequant> 1.7-0.rc1.4.mga4
+ Revision: 457356
- revised cups-avahi-no-threaded patch which fixes segfault

* Sun Jul 21 2013 tv <tv> 1.7-0.rc1.3.mga4
+ Revision: 456677
- fix segfault (Joseph Wang)

* Wed Jul 17 2013 tv <tv> 1.7-0.rc1.2.mga4
+ Revision: 455225
- disable %%post action for cups-lpd: it's a socket, not a service

* Wed Jul 17 2013 tv <tv> 1.7-0.rc1.1.mga4
+ Revision: 455209
- RC1
- sync with FC
- remove pstops cost factor tweak (fixed in cups-filters 1.35)
- sync with FC:
  o use IP_FREEBIND socket option when binding listening sockets (rhz#970809)
  o don't link against libgcrypt needlessly
  o added usblp quirk for Canon PIXMA MP540 (rhz#967873)
  o default to IPP/1.1 for now (bug #977813)
  o fix for DNSSD name resolution

* Fri Jun 14 2013 tv <tv> 1.7-0.b1.3.mga4
+ Revision: 442974
- prevent stringpool damage leading to memory leaks (RH#974048)

* Thu Jun 13 2013 tv <tv> 1.7-0.b1.2.mga4
+ Revision: 442884
- relax requires

* Thu Jun 13 2013 tv <tv> 1.7-0.b1.1.mga4
+ Revision: 442832
- kill static libs
- add NCP backend
- kill more useless stuff
- migrate cups-lpd from xinetd to systemd socket activatable service
- use parallel make
- like FC, add a filesystem sub-package that own /usr/lib/cups/backend
  and the like, thus enabling packages that provide their own backends
  (such as samba-client and bluez-cups) to require only cups-filesystem
  and not the whole printing system

* Thu Jun 13 2013 tv <tv> 1.7-0.b1.mga4
+ Revision: 442516
- 1.7 beta1
- drop empty php-cups

* Tue Jun 04 2013 tv <tv> 1.6.2-4.mga4
+ Revision: 437133
- favor PDF printing over PS printing
  (http://www.linuxfoundation.org/collaborate/workgroups/openprinting/pdf_as_standard_print_job_format)

* Tue Jun 04 2013 tv <tv> 1.6.2-3.mga4
+ Revision: 437098
- requires cups-filters
- fix conflicts with cups-filters
- kill file require

* Sat Jun 01 2013 sander85 <sander85> 1.6.2-2.mga4
+ Revision: 434044
- Fix requires (usrmove)

* Thu May 30 2013 tv <tv> 1.6.2-1.mga4
+ Revision: 433418
- adjust file list
- adjust file list
- parallel backend is dead
- serial backend is dead
- adjust file list
- disable broken poll_ppd_base
- new release
- sync patches with FC
- drop merged patches

* Sun Mar 24 2013 colin <colin> 1.5.4-9.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Tue Jan 15 2013 colin <colin> 1.5.4-8.mga3
+ Revision: 388297
- Fix up tmpfiles support (corrected groups to what the code uses)
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 tmb <tmb> 1.5.4-7.mga3
+ Revision: 339330
- Dont enable IP-based systemd socket activation by default (mitigates CVE-2012-6094)

* Fri Dec 28 2012 cjw <cjw> 1.5.4-6.mga3
+ Revision: 335892
- patch104: usb backend exceptions for specific devices (from ubuntu/fedora)
- patch105: support for apple airprint (from ubuntu)

* Thu Dec 27 2012 cjw <cjw> 1.5.4-5.mga3
+ Revision: 335657
- drop exit 0 from post script that caused the cups service to be disabled after install (mga #8507)

* Thu Dec 20 2012 oden <oden> 1.5.4-4.mga3
+ Revision: 333330
- sync with mga2 updates

* Fri Dec 07 2012 oden <oden> 1.5.4-3.mga3
+ Revision: 327857
- P102: security fix for CVE-2012-5519 (upstream, redhat)
- merge spec file changes from fedora to deal with the new cups-files.conf file
- xinetd is not needed in buildrequires

* Thu Aug 02 2012 cjw <cjw> 1.5.4-2.mga3
+ Revision: 277717
- don't use portreserve, systemd will do this job

* Sat Jul 28 2012 cjw <cjw> 1.5.4-1.mga3
+ Revision: 275393
- new version 1.5.4
- do not blacklist the usblp driver, this should not be needed anymore according to upstream
- pass the full path to pdftops to configure so it does not find it in /bin due to /usr move

* Wed May 30 2012 guillomovitch <guillomovitch> 1.5.3-5.mga3
+ Revision: 250494
- ship tmpfiles to support legacy parallel printers
- drop sysinit support
- small spec cleanup
- new version
- sync fedora patches

* Sat Apr 28 2012 tmb <tmb> 1.5.2-5.mga2
+ Revision: 233653
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 1.5.2-4.mga2
+ Revision: 233546
- rebuild for versioned rpm-helper requires

* Mon Apr 02 2012 zezinho <zezinho> 1.5.2-3.mga2
+ Revision: 227831
- blacklist usblp as it prevents usb printer detection

* Mon Mar 26 2012 anssi <anssi> 1.5.2-2.mga2
+ Revision: 226537
- apply udev rules immediately in %%post, while changing the rules to be
  run on ACTION=="change" as well (part of bug #3616 fix (automatic printer
  installation))
- make cups %%pre more robust when cups is uninstalled and reinstalled
  multiple times

* Tue Feb 14 2012 colin <colin> 1.5.2-1.mga2
+ Revision: 208638
- New version: 1.5.2
- Add Hungarian translation
- Drop patches applied upstream
- Rediff (resync with Fedora) patches which do not apply

* Thu Dec 22 2011 fwang <fwang> 1.5.0-2.mga2
+ Revision: 186112
- rebuild for new libtiff

* Tue Dec 13 2011 dmorgan <dmorgan> 1.5.0-1.mga2
+ Revision: 181225
- New version 1.5.0
  Sync with Fedora
  Clean spec file

* Wed Oct 26 2011 doktor5000 <doktor5000> 1.4.8-3.mga2
+ Revision: 158294
- removed -fPIC from CFLAGS and CXXFLAGS
- properly add our {C,CXX,LD)FLAGS via %%setup_compile_flags
- exported our LDFLAGS as DSOFLAGS as cups uses those internally
- remove stripping handling, was not working before
- use %%optflags and %%ldflags for compiling the additional tools
- enable _disable_ld_no_undefined for the PHP module
- removed seperate debug handling
  o enabled back proper creation of -debug packages
  o moved debug symbols back from binary packages to -debug packages
- removed obsolete empty %%defattr and %%clean sections
- fixed CVE-2011-3170, heap-based buffer overflow allows remote attackers
  to possibly execute arbitrary code (str3914.patch, from upstream)

* Sat Sep 10 2011 fwang <fwang> 1.4.8-2.mga2
+ Revision: 142089
- rebuild for new libpng

* Thu Sep 08 2011 tv <tv> 1.4.8-1.mga2
+ Revision: 141579
- add missing LSB keywords
- rediff patch 35
- new release

* Mon Jun 20 2011 tv <tv> 1.4.6-4.mga2
+ Revision: 110405
- cups-devel requires gnutls-devel, otherwise cups-config fails

* Mon Mar 21 2011 dmorgan <dmorgan> 1.4.6-3.mga1
+ Revision: 75102
- Do not build in bootstrap mode anymore
- Remove old and buggy pdfdistiller ( tks to Luc Menut #483 )

* Sat Feb 19 2011 blino <blino> 1.4.6-2.mga1
+ Revision: 54313
- move printer device acl fix from system-config-printer-udev to cups
  (so that cups works standalone)

* Wed Jan 12 2011 dmorgan <dmorgan> 1.4.6-1.mga1
+ Revision: 7269
- Fix file list
- Do not make check now
- Rebuild with htmldoc
- Do not build htmldoc for now
- Do not build with avahi support for now
- Do not build php support for now
- Remove mdv macros
- Remove mdv macros
- imported package cups
+ ahmad <ahmad>
- imported package cups


* Sat Jan 08 2011 Oden Eriksson <oeriksson@mandriva.com> 1.4.6-1mdv2011.0
+ Revision: 630336
- 1.4.6

* Sat Nov 13 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-1mdv2011.0
+ Revision: 597089
- 1.4.5
- rediffed P1012 (the avahi patch)

* Tue Oct 26 2010 Claudio Matsuoka <claudio@mandriva.com> 1.4.4-4mdv2011.0
+ Revision: 589545
- Apply SUSE patch to revert CUPS STR #3461 (fixes bug #61009)

* Thu Oct 21 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.4-3mdv2011.0
+ Revision: 587086
- rebuild for latest openssl
- use standard macro to allow automatic update
- renumber the patches to match fedora, so as to make comparaison easier

* Fri Sep 10 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.4-2mdv2011.0
+ Revision: 577108
- ensure build with debug symbols by default

* Thu Sep 09 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.4-1mdv2011.0
+ Revision: 577003
- new version
- rediff patches 35, 1015, 1017
- drop patches 1038, 1039, 1040, 1041 (merged upstream)

* Fri Jun 18 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.3-3mdv2010.1
+ Revision: 548314
- added some upstream security patches

* Thu Jun 17 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.4.3-2mdv2010.1
+ Revision: 548231
- add krb5-devel build dependency

* Thu Apr 01 2010 Tiago Salem <salem@mandriva.com.br> 1.4.3-1mdv2010.1
+ Revision: 530727
- reenable the id po file

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - new version
    - rediff usb patch
    - fix some tests

* Fri Mar 26 2010 Tiago Salem <salem@mandriva.com.br> 1.4.2-6mdv2010.1
+ Revision: 527859
- oops, forgot to remove some lines concerning the last commit
- move udev patch to system-config-printer-dev package, as we need the right permission on devices even when cups is not installed yet
- bump release

* Fri Mar 26 2010 Tiago Salem <salem@mandriva.com.br> 1.4.2-5mdv2010.1
+ Revision: 527675
- fix udev rule number 69 to properly match usb printers (fix #56298)
- bump release

* Mon Jan 11 2010 Funda Wang <fwang@mandriva.org> 1.4.2-4mdv2010.1
+ Revision: 489461
- rebuild for new libjpegv8

* Wed Dec 09 2009 Tiago Salem <salem@mandriva.com.br> 1.4.2-3mdv2010.1
+ Revision: 475699
- re-add patch to keep compatibility with previously configured printers.
- bump relase

* Wed Dec 09 2009 Tiago Salem <salem@mandriva.com.br> 1.4.2-2mdv2010.1
+ Revision: 475605
- disable the usblp load in the initscript, as this modules does not exist aymore
- disable usblp + libusb patch
- bump release

* Tue Nov 10 2009 Tiago Salem <salem@mandriva.com.br> 1.4.2-1mdv2010.1
+ Revision: 464296
- cups 1.4.2

* Fri Oct 30 2009 Gustavo De Nardin <gustavodn@mandriva.com> 1.4.1-12mdv2010.0
+ Revision: 460224
- fixed "lp user fix" udev rules so they do not apply to every plugged device

* Tue Oct 27 2009 Gustavo De Nardin <gustavodn@mandriva.com> 1.4.1-11mdv2010.0
+ Revision: 459603
- only run setfacl when the device is added

* Mon Oct 26 2009 Gustavo De Nardin <gustavodn@mandriva.com> 1.4.1-10mdv2010.0
+ Revision: 459433
- Let printers have an ACL allowing rw for user lp, as our CUPS runs
  backends as lp:sys (bug 49407).

* Mon Oct 19 2009 Gustavo De Nardin <gustavodn@mandriva.com> 1.4.1-9mdv2010.0
+ Revision: 458294
- stop using libpaper, Fedora also doesn't use it, seems unneeded anymore

* Sat Oct 17 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.1-8mdv2010.0
+ Revision: 457996
- Add no-hostname-broadcast patch from Ubuntu, Launchpad #449586: Do not
  use hostnames for broadcasting print queues and managing print queues
  broadcasted from other servers by default. Many networks do not have
  valid host names for all machines
- Update usblp-libusp patch from Ubuntu: Fixed a bug of modifying the
  URI of the current print queue when comparing it with discovered
  URIs. Made the USB backend also compatible with URIS generated by old
  versions of CUPS, without serial number or with "serial=?"
  (Launchpad #450513)
- Enable avahi support; lower error to warning in avahi patch when avahi
  is not running, in order to make the test suite succeed without
  running avahi (from Debian/Ubuntu)

* Wed Oct 14 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.1-7mdv2010.0
+ Revision: 457453
- Sync with Fedora:
  * Fixed orientation of page labels when printing text in landscape
    mode (RH bug #520141, STR #3334).
  * Replace str3356 patch by new patch approved by upstream

* Mon Oct 05 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.1-6mdv2010.0
+ Revision: 454122
- No longer depends on dynamic

* Sun Oct 04 2009 Funda Wang <fwang@mandriva.org> 1.4.1-5mdv2010.0
+ Revision: 453332
- obsoletes cupsddk also

* Sun Oct 04 2009 Funda Wang <fwang@mandriva.org> 1.4.1-4mdv2010.0
+ Revision: 453318
- rebuild

* Sat Oct 03 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.1-3mdv2010.0
+ Revision: 452766
- Fix BuildRequires, fixing build with usblp compatibility patch
- Remove build fix patch: included in usblp compatibility patch
- Add Fedora patch: Don't use cached PPD for raw queue (RH bug #526405)
- Add Debian patch: Use both usblp and libusb, to prevent trouble if
  kernel usblp module is loaded. Disabled for now because of build
  problems on x86_64

* Thu Sep 24 2009 Olivier Blin <oblin@mandriva.com> 1.4.1-2mdv2010.0
+ Revision: 448232
- allow to bootstrap build by breaking build dep loop
  gtk->cups->poppler->gtk (from Arnaud Patard)

* Mon Sep 14 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.1-1mdv2010.0
+ Revision: 440972
- Add patch to fix build on x86_64 due to conflicting declarations
- Dont't run cups with nice level 14 by default: makes no sense on
  servers, no proof that it helps interactivity on desktops, and should
  not be needed with recent kernels anyway
- Update avahi patch from Fedora: Fixes the dnssd backend so that it
  only reports devices once avahi resolution has completed.  This
  makes it report Device IDs
- Install logrotate configuration
- Update to new version 1.4.1
- Remove patches for issues fixed upstream
- Test-suite is now working again

* Wed Sep 02 2009 Frederik Himpe <fhimpe@mandriva.org> 1.4.0-2mdv2010.0
+ Revision: 426016
- Merge with cups from testing branch:
  * Update to cups 1.4
  * Add patch fixing permisions of installed files
  * Add Fedora patches
  * Rediff recommended patch
  * Remove old, unneeded patches

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 1.3.10-4mdv2010.0
+ Revision: 416592
- rebuilt against libjpeg v7

* Sat May 30 2009 Funda Wang <fwang@mandriva.org> 1.3.10-3mdv2010.0
+ Revision: 381443
- build with latest gnutls 2.8

* Wed Apr 22 2009 Gustavo De Nardin <gustavodn@mandriva.com> 1.3.10-2mdv2009.1
+ Revision: 368615
- Make cups run usb backend as root to workaround device permissions issues (bug #49407)

* Fri Apr 17 2009 Oden Eriksson <oeriksson@mandriva.com> 1.3.10-1mdv2009.1
+ Revision: 367896
- use poppler as the backend and fix deps
- enable acl support
- disable "make test" for now due to unknown problems in the test suite
- fix build deps (poppler + ghostscript)
- added P31 from debian in an attempt to make the tests pass
- 1.3.10

* Wed Jan 21 2009 Eugeni Dodonov <eugeni@mandriva.com> 1.3.9-4mdv2009.1
+ Revision: 332230
- Patched pdfdistiller to prevent CVE-2008-5377 (arbitrary local file overwrite
  via symlinks).

* Tue Dec 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.9-3mdv2009.1
+ Revision: 318064
- drop the CVE-2008-1373 patch (P19), it's fixed since 1.3.7,
  spotted by fhimpe

* Tue Dec 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.9-2mdv2009.1
+ Revision: 318055
- rediffed one fuzzy patch

* Fri Oct 10 2008 Frederik Himpe <fhimpe@mandriva.org> 1.3.9-1mdv2009.0
+ Revision: 291529
- Update to new version 1.3.9 (fixes 3 integer overflow security
  bugs)

* Wed Jul 30 2008 Frederik Himpe <fhimpe@mandriva.org> 1.3.8-1mdv2009.0
+ Revision: 256478
- New upstream version 1.3.8
- Remove str2086, str2865 and CVE-2008-1722 patches: all of them
  were integrated upstream
- Add new Indonesian translation to file list

  + Tiago Salem <salem@mandriva.com.br>
    - fix bug #41073 by using an upstream patch.
    - bump release
    - fix for crash when enabling printers with missing backends. (#41073)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - drop useless ldconfig in %%preun (it is already correctly done in %%postun)

* Thu May 22 2008 Frederik Himpe <fhimpe@mandriva.org> 1.3.7-2mdv2009.0
+ Revision: 210108
- Add peercred.patch from Fedora to fix build with gcc 4.3
- Do the lib64 substitution also on the configure script, because the
  one done in the m4 file has no effect if configure is not regenerated
  (which is currently the case)

* Sun May 18 2008 Frederik Himpe <fhimpe@mandriva.org> 1.3.7-1mdv2009.0
+ Revision: 208559
- Add patch from Fedora to fix security problem CVE-2008-1722
- Try to get the licenses right
- Enable test suite, add upstream patch to fix test suite failure
  (http://www.cups.org/str.php?L2806)
- Remove CVE-2008-0047.patch, cups 1.3.7 already includes it
- Remove cups-1.3.6-disconnected-usb-increases-cpu-usage.patch, an
  equivalent fix was integrated in Cups 1.3.7
- Update to version 1.3.7

* Mon Apr 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.6-6mdv2009.0
+ Revision: 196241
- really attempt to fix #23846 (portmap randomly bind ports used by other application)

* Tue Apr 01 2008 Tiago Salem <salem@mandriva.com.br> 1.3.6-5mdv2008.1
+ Revision: 191434
- Patch for CVE-2008-1373.

* Wed Mar 26 2008 Frederik Himpe <fhimpe@mandriva.org> 1.3.6-4mdv2008.1
+ Revision: 190239
- Patch for CVE-2008-0047 (remotely exploitable buffer overflow),
  taken from Debian

* Tue Mar 25 2008 Tiago Salem <salem@mandriva.com.br> 1.3.6-3mdv2008.1
+ Revision: 190046
- fix for bug #38820
- bump release

* Sun Mar 16 2008 Funda Wang <fwang@mandriva.org> 1.3.6-2mdv2008.1
+ Revision: 188140
- locales should not be installed at every case

* Mon Feb 25 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.6-1mdv2008.1
+ Revision: 174766
- Remove unapplied patches and make rpmlint happy.
- New upstream: 1.3.6. Closes: #38032
- Added patch str2703.

* Wed Jan 30 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.5-5mdv2008.1
+ Revision: 160417
- Really don't put /usr/local dirs under %%files section.

* Wed Jan 23 2008 Thierry Vignaud <tv@mandriva.org> 1.3.5-4mdv2008.1
+ Revision: 157242
- rebuild with fixed %%serverbuild macro

  + Marcelo Ricardo Leitner <mrl@mandriva.com>
    - Bunzip text sources.
    - Match owners according to cupsd. Closes: #32330

* Sun Jan 13 2008 Funda Wang <fwang@mandriva.org> 1.3.5-3mdv2008.1
+ Revision: 150450
- rebuild against latest gnutls

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1.3.5-2mdv2008.1
+ Revision: 137455
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Dec 19 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.5-1mdv2008.1
+ Revision: 134898
- New upstream: 1.3.5
- Removed patch CVE-2007-4352-5392-5393: already applied.

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 10 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.4-4mdv2008.1
+ Revision: 116986
- Do not check for errors while creating /usr/local/lib/printdriver
  Closes: #35993

* Tue Nov 20 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.4-3mdv2008.1
+ Revision: 110713
- Added patch for cups-1.3.0-CVE-2007-{4352,5392,5393}

* Sat Nov 17 2007 Funda Wang <fwang@mandriva.org> 1.3.4-2mdv2008.1
+ Revision: 109291
- rebuild for new lzma

* Thu Nov 01 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.4-1mdv2008.1
+ Revision: 104391
- New upstream: 1.3.4
- Fix the enable of raw printing by default. Closes: #34614

* Wed Oct 10 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.3-1mdv2008.1
+ Revision: 96910
- Only rebuild autotools if we are using a snapshot.
- Removed patch str2472: It's already applied on this version.
- New upstream: 1.3.3

* Wed Sep 26 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.0-3mdv2008.0
+ Revision: 93180
- Fix icondir on configure.
- Replay svn_corrupted commit 150560:
  - Added support for LSB 3.2. Closes: #28383

* Thu Sep 13 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.3.0-2mdv2008.0
+ Revision: 85025
- Do not force requires on xinetd, as it's not used by default.

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 1.3.0-1mdv2008.0
+ Revision: 69816
- fix build
- kill file require on update-alternatives

  + Oden Eriksson <oeriksson@mandriva.com>
    - fix RPM GROUPS

  + Marcelo Ricardo Leitner <mrl@mandriva.com>
    - Added patch str2472: adds fallbacks in case browser-supplied languages are
      not found.
    - New upstream: 1.3.0
    - Rediffed recommended patch.

* Fri Aug 10 2007 David Walluck <walluck@mandriva.org> 1.2.12-6mdv2008.0
+ Revision: 61627
- remove newline from beginning of %%description tags (shows up in, e.g., `rpm -qi')

* Fri Aug 10 2007 Funda Wang <fwang@mandriva.org> 1.2.12-5mdv2008.0
+ Revision: 61565
- no hplip service any more
- use %%_extension for man pages
- man-pages are lzma-ed

* Wed Jul 25 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.12-4mdv2008.0
+ Revision: 55266
- Move cups-config back to the lib-devel package.
  http://bugzilla.gnome.org/show_bug.cgi?id=459732

* Tue Jul 24 2007 David Walluck <walluck@mandriva.org> 1.2.12-3mdv2008.0
+ Revision: 55055
- fix a few instances of /etc and /var that were not macros
- fix changing of perms in scriptlets which should be done in %%files (and causes rpm -V to fail)
- remove echo in %%post which should not be done

* Fri Jul 13 2007 Funda Wang <fwang@mandriva.org> 1.2.12-2mdv2008.0
+ Revision: 51851
- New version

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 1.2.11-2mdv2008.0
+ Revision: 45162
- using new serverbuild macro (-fstack-protector-all)

  + Marcelo Ricardo Leitner <mrl@mandriva.com>
    - Do not overwrite snmp backend anymore: the new upstream one is newer than
      ours and also fixes the related bug.

* Tue May 15 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.11-1mdv2008.0
+ Revision: 26962
- New upstream: 1.2.11


* Tue Apr 03 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.10-2mdv2007.1
+ Revision: 150418
- Added patch recommended: patch away the removal of the Recommended tag.

* Wed Mar 21 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.10-1mdv2007.1
+ Revision: 147258
- New bugfixes upstream: 1.2.10

* Sat Mar 17 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.9-1mdv2007.1
+ Revision: 145647
- New upstream 1.2.9 which contains security fixes.

* Mon Mar 12 2007 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.7-2mdv2007.1
+ Revision: 141961
- Release bump.
- Prefer xdg-open (xdg-utils) than html-view (kde only) for desktop menus.
  Closes: #29202
- Added /etc/sysconfig/cups to files section.
- Nice cups daemon. Closes: #16387
- Bunzip startup script.

* Fri Nov 24 2006 Marcelo Ricardo Leitner <mrl@mandriva.com> 1.2.7-1mdv2007.1
+ Revision: 86921
- New upstream: 1.2.7
- Removed all unused and commented patches.
- Removed patch 'r5958-bugfixes': already applied.
- Import cups

* Thu Sep 14 2006 Till Kamppeter <till@mandriva.com> 1.2.3-5mdv2007.0
- Overtaken upstream bug fix patch from Debian (Patch 38: "All
  Documents" link in on-line help was missing a trailing slash, job
  history with Polish web interface, "Reprint job" button did not
  work, daemon did not always report printer or job events properly,
  daemon did not respect backend error codes, problems with UTF-8 in
  job names and on the command line, custom page size problem).
- Removed patch 36 and 37 (part of patch 38 now).

* Thu Sep 14 2006 Till Kamppeter <till@mandriva.com> 1.2.3-4mdv2007.0
- Added missing BuildRequires for image and directory service support.

* Thu Sep 14 2006 Till Kamppeter <till@mandriva.com> 1.2.3-3mdv2007.0
- It sometimes happens that lpstat lets the CUPS daemon fall into an 
  infinite loop. Patch 36 and 37, proposed by Mike Sweet on
  http://www.cups.org/str.php?L1968 should fix the problem (should fix bug
  25186).
- If there is a directory named /usr/lib64/cups, rename it to
  /usr/lib/cups and let /usr/lib64/cups be a symlink (bug 25517).

* Wed Sep 06 2006 Till Kamppeter <till@mandriva.com> 1.2.3-2mdv2007.0
- Added "Requires: cups-common" to the libcups-devel subpackage to
  assure that cups-config is present.

* Thu Aug 31 2006 Till Kamppeter <till@mandriva.com> 1.2.3-1mdv2007.0
- Updated to CUPS 1.2.3 (Tons of bug fixes, see
  http://www.cups.org/articles.php?L407).
- Simplified conditional build for MDV 2006/Corporate 4 and MDV 2007
  (Thanks to Olivier Thauvin).

* Wed Aug 09 2006 Till Kamppeter <till@mandriva.com> 1.2.2-4mdv2007.0
- Updated PAM configuration file (bug 24199).

* Sat Aug 05 2006 Till Kamppeter <till@mandriva.com> 1.2.2-3mdv2007.0
- Several fixes on the "snmp" network printer autodiscovery backend.

* Thu Aug 03 2006 Frederic Crozat <fcrozat@mandriva.com> 1.2.2-2mdv2007.0
- Rebuild with latest dbus

* Thu Jul 20 2006 Till Kamppeter <till@mandriva.com> 1.2.2-1mdv2007.0
- Updated to CUPS 1.2.2 (Tons of bug fixes, see
  http://www.cups.org/articles.php?L397).

* Wed Jul 05 2006 Till Kamppeter <till@mandriva.com> 1.2.1-4mdv2007.0
- Uncompressed patches.

* Wed Jul 05 2006 Till Kamppeter <till@mandriva.com> 1.2.1-3mdv2007.0
- Removed absolute paths from /etc/pam.d/cups (bug 22960).

* Thu Jun 22 2006 Laurent MONTEL <lmontel@mandriva.com> 1.2.1-2
- Rebuild

* Tue May 23 2006 Till Kamppeter <till@mandriva.com> 1.2.1-1mdk
- Updated to CUPS 1.2.1 (The most important "dot-zero" version
  bugs are fixed now).
- Removed patch 35 (merged upstream).
- Do not build in debug mode any more,

* Fri May 19 2006 Till Kamppeter <till@mandriva.com> 1.2.0-4mdk
- Delete broken update-alternatives links when updating to this
  version of CUPS (containing the correct links).

* Thu May 18 2006 Till Kamppeter <till@mandriva.com> 1.2.0-3mdk
- Expanded use of update-alternatives to not conflict with
  papi-commands package.
- Fixed update-alternatives mechanism for the man pages.
- Set some links to find man pages more easily.

* Wed May 17 2006 Till Kamppeter <till@mandriva.com> 1.2.0-2mdk
- Fixes raw data files not being accepted when
  "application/octet-stream ..." rules in /etc/cups/mime.* files are active
  (bug 21814, STR 1667).

* Thu May 11 2006 Till Kamppeter <till@mandriva.com> 1.2.0-1mdk
- Updated to CUPS 1.2.0 official release.
- Fixed alternatives setup for the man pages.

* Mon May 08 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5497.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5497.

* Fri Apr 28 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5470.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5470 (Fix in web
  interface: Once you are in SSL mode, you stay there when navigating
  through the web interface).
- Allow remote administration via web interface from the local network
  by default (admin connections are always SSL-encryoted, so no security
  problem).

* Thu Apr 27 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5464.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5464 (Shortly after
  CUPS 1.2rc3 release).

* Tue Apr 25 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5454.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5454 (Added "Encryption
  Required" to "/admin" location in /etc/cups/cupsd.conf, so that all
  administration transactions are done via SSL and input into the web
  interface cannot get lost when the web interface switches from http
  to https in the end of the add printer wizard).
- Added IEEE-1284 device ID support to "poll_ppd_base".

* Mon Apr 24 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5453.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5441 (SNMP
  auto-discovery not hanging any more on IPP device which requests a
  password, many other bug fixes, Polish translation).

* Fri Apr 21 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5441.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5441 (Fixes on SNMP
  auto-discovery).
- Moved cups-config from the libcups2-devel to the cups-common package,
  for easy checking of currently installed CUPS version.

* Thu Apr 20 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5431.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5431 (SNMP auto-discovery
  for network printers, as suggested on the OSDL Printing Summit in Atlanta).

* Thu Apr 13 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5390.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5390.
- Added "BuildRequires: libgnutls-devel", GNU TLS is needed for automatic
  certificate generation for SSL-encrypted access.
- Added /usr/lib/cups/driver directory for PPD file generators.

* Tue Apr 11 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5389.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5389.

* Tue Apr 11 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5388.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5388 (Somewhat after
  the 1.2rc2 release).

* Tue Apr 04 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5368.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5368.
- When building for the Mandriva Linux Corporate 4 products, do not
  require DBUS for building, as CUPS 1.2 uses a new DBUS generation
  which is not available in the Mandriva-2006-based Corporate products.

* Sat Apr 01 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5361.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5361.

* Fri Mar 31 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5357.3mdk
- Fixed 64-bit issue with /usr/lib/cups correctly. It must stay
  /usr/lib/cups to be compatible with third-party filter/backend
  installations (See http://www.cups.org/str.php?L1524).
- Added compatibility link from /usr/lib/cups to /usr/lib64/cups on x86_64
  systems (will be removed when all other Mandriva packages with CUPS
  backends/filters are updated).
- Worked around bug on Mandriva compilation cluster (32-bit machine has
  /usr/lib64 directory).

* Fri Mar 31 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5357.2mdk
- Corrected hard-coded /usr/lib/cups.

* Fri Mar 31 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5357.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5357.
- Added "Requires: udev dynamic" to assure that device files (like
  /dev/usb/lp0) are created and their ownerships/permissions are set 
  correctly (bug 21461).

* Wed Mar 29 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5344.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5344 (Somewhat after
  the 1.2rc1 release).

* Sun Mar 19 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5312.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5312 (Somewhat after
  the 1.2b2 release).

* Thu Mar 09 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5257.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5257 (SHOWSTOPPPER
  FIX! The original CUPS 1.2beta1 did not print at all!).

* Thu Mar 09 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5256.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5256 (This is the 
  CUPS 1.2beta1 release).

* Tue Mar 07 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5239.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5239.
- Made the no non-existing /etc/cups/client.conf a %%ghost.

* Tue Feb 28 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5205.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5205 (Fixed margins
  for N-up printing).

* Tue Feb 28 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5201.2mdk
- Added "BuildRequires: php-cli" so that "./configure" recognizes the
  presence of PHP.

* Tue Feb 28 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5201.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5201.
- Added non-existing files /etc/cups/printers.conf and
  /etc/cups/classes.conf as %%ghost and %%config(noreplace) so that the
  old files of CUPS 1.1 do not get renamed when updating to CUPS 1.2.

* Mon Feb 27 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5186.2mdk
- Obsoleted out old "php4-cups" package from contrib.
- Named file in /etc/php.d/ as in the old "php4-cups" package.

* Sun Feb 26 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5186.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5186.

* Sun Feb 26 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5183.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5183.
- Added new sub package "php-cups" with PHP bindings for the CUPS library.

* Fri Feb 24 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5168.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5168 (Do not accept
  invalid directories for temporary files).

* Fri Feb 24 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5165.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5165 (This is probably
  really the fix for bug 21094).

* Fri Feb 24 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5162.2mdk
- Added backward compatibility links for "enable" and "disable" commands.

* Fri Feb 24 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5162.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5162.

* Thu Feb 23 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5130.2mdk
- Added "--with-system-groups=lpadmin root" to the "./configure" command 
  line and added/removed the "lpadmin" in the pre-install/post-uninstall
  scripts. This way the group "sys" can stay the standard CUPS group. This
  is the way as it is also done in Debian GNU/Linux (see CUPS STR 1434).

* Fri Feb 17 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5130.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5130.

* Thu Feb 16 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5120.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5120.
- Removed hardcoded "chgrp" from Makefiles, set group ownerships in
  %%files section.
- Set permissions of /etc/cups/mime.convs and /etc/cups/mime.types to
  644 (world-readable) so that HP's hp-sendfax utility works for normal
  users.
- Added "unset TMPDIR" to the start-up script of CUPS (cups.startup).

* Mon Feb 06 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5083.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5083.

* Wed Feb 01 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.5046.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 5046 (Add system 
  management interface for power management/sleep, network changes, hostname
  changes, etc. to cupsd, updated man pages, added whitespace and line 
  ending checks to cupstestppd, fixed many file permission issues. tons 
  of bug fixes and polishing).

* Mon Jan 23 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.4964.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4964 (mailto: notifier
  added).
- Removed patch 34 (merged upstream).

* Thu Jan 19 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.4951.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4951 (Bug 20504:
  Fixed last missing problem, bad7.pdf from Chris Evans, updated all 
  command-line programs to support "-h" and "-U", small fixes).

* Wed Jan 18 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.4945.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4945 (Bug 20504:
  Security update for CVE-2005-3191,3192,3193, overflows in goo/gmem.c,
  additional overflow issues discovered by Chris Evans, CVE-2005-3624,
  3625,3626,3627, fixed also print queue set up of auto-detected printers
  with the web interface).

* Wed Jan 18 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.4929.2mdk
- Added libpaper support.

* Sat Jan 14 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.4929.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4929.
- Removed correction of path for pam_appl.h (fixed upstream).
- Rediffed patch 34.
- Re-introduced %%{_datadir}/locale in %%files section.

* Mon Jan 09 2006 Till Kamppeter <till@mandriva.com> 1.2.0-0.4892.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4892.
- Added htmldoc to "BuildRequires:".
- Corrected path for pam_appl.h.
- Removed %%{_datadir}/locale from %%files section.
- Reverted the use of the %%configure2_5x macro back to the direct
  ./configure call, as the use of the macro broke CUPS totally (bug 20511).
- Added STATEDIR definition to "make" and "make install" calls
  (/var/run/cups/).

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 1.2.0-0.4876.5mdk
- convert parallel init to LSB

* Wed Jan 04 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.2.0-0.4876.3mdk
- fix build on x86_64
- patch 34: fix build on x86_64 (-fpie overided -fPIC)

* Sat Dec 31 2005 Couriousous <couriousous@mandriva.org> 1.2.0-0.4876.2mdk
- Add parallel init stuff

* Fri Dec 16 2005 Till Kamppeter <till@mandriva.com> 1.2.0-0.4876.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4876.

* Wed Dec 07 2005 Till Kamppeter <till@mandriva.com> 1.2.0-0.4865.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4865.

* Thu Nov 24 2005 Till Kamppeter <till@mandriva.com> 1.2.0-0.4843.1mdk
- Updated to CUPS 1.2 development snapshot SVN rev 4843.
- Temporarily deactivated patches 2, 3, 22, 27, 33.

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 1.1.23-19mdk
- rebuilt against openssl-0.9.8a

* Sat Oct 29 2005 Till Kamppeter <till@mandriva.com> 1.1.23-18mdk
- Introduced a timeout when waiting for CUPS daemon listening (bug
  19255).
- Replaced dbus patch by newer one from Red Hat (current one did not build
  any more).

* Fri Aug 19 2005 Till Kamppeter <till@mandriva.com> 1.1.23-17mdk
- Removed facility to automatically set up print queues when starting CUPS.
  This can cause problems during installation.

* Thu Aug 18 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.1.23-16mdk
- 64-bit fixes

* Thu Aug 18 2005 Till Kamppeter <till@mandriva.com> 1.1.23-15mdk
- Moved comment away from "%%postun".

* Wed Aug 17 2005 Till Kamppeter <till@mandriva.com> 1.1.23-14mdk
- Turned off automatic re-enabling of print queues on CUPS start-up
  because we have the new CUPS backend wrapper no which prevents queues
  from being disabled automatically.

* Sun Aug 14 2005 Till Kamppeter <till@mandriva.com> 1.1.23-13mdk
- SECURITY FIX: Fixes CAN-2005-2097: Vulnerability on PDF processing 
  (patch 35).
- Added "Requires: xinetd" to "cups" packages. It is needed for the
  "cups-lpd" mini daemon.

* Thu Jul 28 2005 Till Kamppeter <till@mandriva.com> 1.1.23-12mdk
- Added automatic re-enabling of print queues and automatic
  print queue setup (both configurable) to /etc/init.d/cups.

* Tue Apr 12 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-11mdk
- Fixed bug 15376: "!(" -> "! (" in /etc/init.d/cups.

* Tue Mar 22 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-10mdk
- Updated Pierre Jarillon's I18n patch, especially there are "Set as
  default" buttons in all languages now.

* Fri Mar 18 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-9mdk
- Revert change of lock file name to have /var/lock/subsys/cups again.
  Handling services with different service name and daemon name is a
  general problem (also with Samba and MySQL) which has to be addressed
  later. Renaming the service to "cupsd" would break other stuff
  (printerdrake, KDE Printing Manager, ...). The bugs 11715, 14727, and 
  14545 cannot be fixed all at once.

* Wed Mar 16 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-8mdk
- Fixed I18n of the CUPS web interface and online help (bug 10598, thanks
  to Pierre Jarillon, jarillon at abul dot org, for the big patch).
- Let online help go into /usr/share/cups/doc and not into /usr/share/doc,
  so that it gets also installed in a minimum installation without
  documentation, otherwise the web interface would be broken in this case
  (Thanks to Raul Dias, raul at dias dot com dot br, for reporting this).

* Wed Mar 02 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-7mdk
- Recode all translations to UTF-8 so that the web interface of CUPS is
  shown correctly, especially with Mozilla.

* Tue Mar 01 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-6mdk
- Removed menu entry for CUPS web interface.

* Fri Feb 18 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-5mdk
- Use /var/lock/subsys/cupsd instead of /var/lock/subsys/cups
  in startup script, to fix bug 11715.
- SECURITY FIX: Fixes CAN-2005-0064/MDKSA-2005:041/Bug 13751: See
  http://www.mandrakesoft.com/security/advisories?name=MDKSA-2005:041

* Fri Feb 11 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-4mdk
- SECURITY FIX: Fixes CAN-2005-0064/MDKSA-2005:018/Bug 13580: See
  http://www.mandrakesoft.com/security/advisories?name=MDKSA-2005:018

* Fri Feb 11 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-3mdk
- Updated CUPS startup script to also check HPLIP.

* Wed Feb 09 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.1.23-2mdk
- multiarch

* Tue Jan 04 2005 Till Kamppeter <till@mandrakesoft.com> 1.1.23-1mdk
- Updated to CUPS 1.1.23 final (Tons of bug fixes: "Media tray empty" on
  USB backend, possible DoS in CUPS daemon, buffer overflow on "hpgltops"
  filter, ...).
- Set "lppasswd" SUID root again, otherwise it does not work.
- Removed support for Mandrakelinux 7.2.
- Fixed icon stuff.

* Tue Nov 30 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.22-2mdk
- Added Red Hat's DBUS support (Patch 27).

* Tue Nov 09 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.22-1mdk
- Updated to CUPS 1.1.22 final.
- Removed Patch 26, it is already applied upstream.

* Tue Oct 12 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.21-1mdk
- Updated to CUPS 1.1.21 final.
- Removed Patch 24 and Patch 25, they are already applied upstream.
- Improved debug mode, now the RPM built in debug mode has really
  unstripped executables.
- Fix the CUPS daemon dieing on "killall -HUP cupsd" (Patch 26, Thanks to
  Tim Waugh from Red Hat, CUPS STR 865 and 928).

* Sat Oct 09 2004 Vincent Danen <vdanen@mandrakesoft.com> 1.1.21-0.rc1.7mdk
- P25: security fix for CAN-2004-0558

* Tue Sep 21 2004 Frederic Lepied <flepied@mandrakesoft.com> 1.1.21-0.rc1.6mdk
- start cups at level 15 to avoid conflicts with RPC programs like
  ypbind (bug #9951)

* Tue Aug 31 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.21-0.rc1.5mdk
- Added switchable debug mode.
- Moved "Provides: lpddaemon" from "cups" to "cups-common" package as we
  support daemon-less CUPS client mode with printerdrake now.

* Sat Aug 21 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.21-0.rc1.4mdk
- If there is no USB printer connected, let the "usb" backend put out
  /dev/usb/lpX as default device file names and not /dev/usblpX.

* Tue Aug 10 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.21-0.rc1.3mdk
- Set temporary directory and other parameters in /etc/xinetd.d/cups-lpd,
  sp that cups-lpd uses the correct temporary directory and
  permissions/ownerships (Anthill bug 879).

* Fri Aug 06 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.1.21-0.rc1.2mdk
- use -fPIC too on ix86

* Thu Jun 10 2004 Till Kamppeter <till@mandrakesoft.com> 1.1.21-0.rc1.1mdk
- Updated to CUPS 1.1.21rc1.
- Perlified patch 6.

* Sat Jun 05 2004 <lmontel@n2.mandrakesoft.com> 1.1.20-6mdk
- Rebuild

